@@ -19,15 +19,12 @@
 #include "feed.h"
 #include "fetcher.h"
 #include "models/errorlogmodel.h"
+#include "networkconnectionmanager.h"
 #include "settingsmanager.h"
 
-#include <solidextras/networkstatus.h>
-
 class AudioManagerPrivate
 {
 private:
-    SolidExtras::NetworkStatus m_networkStatus;
-
     KMediaSession m_player = KMediaSession(QStringLiteral("kasts"), QStringLiteral("org.kde.kasts"));
 
     Entry *m_entry = nullptr;
@@ -277,12 +274,11 @@ void AudioManager::setEntry(Entry *entry)
     d->m_entry = nullptr;
 
     // Check if the previous track needs to be marked as read
-    // TODO: make grace time a setting in SettingsManager
     if (oldEntry && !signalDisconnect) {
         qCDebug(kastsAudio) << "Checking previous track";
         qCDebug(kastsAudio) << "Left time" << (duration() - position());
         qCDebug(kastsAudio) << "MediaStatus" << d->m_player.mediaStatus();
-        if (((duration() > 0) && (position() > 0) && ((duration() - position()) < SKIP_TRACK_END))
+        if (((duration() > 0) && (position() > 0) && ((duration() - position()) < SettingsManager::self()->markAsPlayedBeforeEnd() * 1000))
             || (d->m_player.mediaStatus() == KMediaSession::EndOfMedia)) {
             qCDebug(kastsAudio) << "Mark as read:" << oldEntry->title();
             oldEntry->enclosure()->setPlayPosition(0);
@@ -298,9 +294,7 @@ void AudioManager::setEntry(Entry *entry)
 
     // do some checks on the new entry to see whether it's valid and not corrupted
     if (entry != nullptr && entry->hasEnclosure() && entry->enclosure()
-        && (entry->enclosure()->status() == Enclosure::Downloaded
-            || (d->m_networkStatus.connectivity() != SolidExtras::NetworkStatus::No
-                && (d->m_networkStatus.metered() != SolidExtras::NetworkStatus::Yes || SettingsManager::self()->allowMeteredStreaming())))) {
+        && (entry->enclosure()->status() == Enclosure::Downloaded || NetworkConnectionManager::instance().streamingAllowed())) {
         qCDebug(kastsAudio) << "Going to change source";
 
         setEntryInfo(entry);
@@ -394,12 +388,16 @@ void AudioManager::play()
     // if we're streaming, check that we're still connected and check for metered
     // connection
     if (isStreaming()) {
-        if (d->m_networkStatus.connectivity() == SolidExtras::NetworkStatus::No
-            || (d->m_networkStatus.metered() != SolidExtras::NetworkStatus::No && !SettingsManager::self()->allowMeteredStreaming())) {
+        if (!NetworkConnectionManager::instance().streamingAllowed()) {
             qCDebug(kastsAudio) << "Refusing to play: no connection or streaming on metered connection not allowed";
+            QString feedUrl, entryId;
+            if (d->m_entry) {
+                feedUrl = d->m_entry->feed()->url();
+                entryId = d->m_entry->id();
+            }
             Q_EMIT logError(Error::Type::MeteredStreamingNotAllowed,
-                            d->m_entry->feed()->url(),
-                            d->m_entry->id(),
+                            feedUrl,
+                            entryId,
                             0,
                             i18n("No connection or streaming on metered connection not allowed"),
                             QString());
@@ -474,13 +472,13 @@ void AudioManager::seek(qint64 position)
 void AudioManager::skipForward()
 {
     qCDebug(kastsAudio) << "AudioManager::skipForward";
-    seek(std::min((position() + SKIP_STEP), duration()));
+    seek(std::min((position() + (1000 * SettingsManager::skipForward())), duration()));
 }
 
 void AudioManager::skipBackward()
 {
     qCDebug(kastsAudio) << "AudioManager::skipBackward";
-    seek(std::max((qint64)0, (position() - SKIP_STEP)));
+    seek(std::max((qint64)0, (position() - (1000 * SettingsManager::skipBackward()))));
 }
 
 bool AudioManager::canGoNext() const
@@ -491,14 +489,12 @@ bool AudioManager::canGoNext() const
             // check if there is a next track
             if (index < DataManager::instance().queue().count() - 1) {
                 Entry *next_entry = DataManager::instance().getEntry(DataManager::instance().queue()[index + 1]);
-                if (next_entry->enclosure()) {
+                if (next_entry && next_entry->enclosure()) {
                     qCDebug(kastsAudio) << "Enclosure status" << next_entry->enclosure()->path() << next_entry->enclosure()->status();
                     if (next_entry->enclosure()->status() == Enclosure::Downloaded) {
                         return true;
                     } else {
-                        SolidExtras::NetworkStatus networkStatus;
-                        if (networkStatus.connectivity() == SolidExtras::NetworkStatus::Yes
-                            && (networkStatus.metered() == SolidExtras::NetworkStatus::No || SettingsManager::self()->allowMeteredStreaming())) {
+                        if (NetworkConnectionManager::instance().streamingAllowed()) {
                             return true;
                         }
                     }
@@ -552,9 +548,12 @@ void AudioManager::playerDurationChanged(qint64 duration)
     qCDebug(kastsAudio) << "AudioManager::playerDurationChanged" << duration;
 
     // Check if duration mentioned in enclosure corresponds to real duration
-    if (duration > 0 && (duration / 1000) != d->m_entry->enclosure()->duration()) {
-        qCDebug(kastsAudio) << "Correcting duration of" << d->m_entry->id() << "to" << duration / 1000 << "(was" << d->m_entry->enclosure()->duration() << ")";
-        d->m_entry->enclosure()->setDuration(duration / 1000);
+    if (d->m_entry && d->m_entry->enclosure()) {
+        if (duration > 0 && (duration / 1000) != d->m_entry->enclosure()->duration()) {
+            qCDebug(kastsAudio) << "Correcting duration of" << d->m_entry->id() << "to" << duration / 1000 << "(was" << d->m_entry->enclosure()->duration()
+                                << ")";
+            d->m_entry->enclosure()->setDuration(duration / 1000);
+        }
     }
 
     qint64 correctedDuration = duration;
@@ -589,7 +588,7 @@ void AudioManager::savePlayPosition()
     checkForPendingSeek();
 
     if (!d->m_lockPositionSaving) {
-        if (d->m_entry) {
+        if (d->m_entry && d->m_entry->enclosure()) {
             if (d->m_entry->enclosure()) {
                 d->m_entry->enclosure()->setPlayPosition(position());
             }
