@@ -29,12 +29,11 @@
 #include "fetcher.h"
 #include "models/downloadmodel.h"
 #include "models/errorlogmodel.h"
+#include "networkconnectionmanager.h"
 #include "settingsmanager.h"
 #include "storagemanager.h"
 #include "sync/sync.h"
 
-#include <solidextras/networkstatus.h>
-
 Enclosure::Enclosure(Entry *entry)
     : QObject(entry)
     , m_entry(entry)
@@ -156,7 +155,7 @@ void Enclosure::download()
         return;
     }
 
-    if (SolidExtras::NetworkStatus().metered() == SolidExtras::NetworkStatus::Yes && !SettingsManager::self()->allowMeteredEpisodeDownloads()) {
+    if (!NetworkConnectionManager::instance().episodeDownloadsAllowed()) {
         Q_EMIT downloadError(Error::Type::MeteredNotAllowed,
                              m_entry->feed()->url(),
                              m_entry->id(),
@@ -263,6 +262,10 @@ void Enclosure::processDownloadedFile()
     if (m_entry->getNew()) {
         m_entry->setNew(false);
     }
+
+    // Trigger update of image since the downloaded file can have an embedded image
+    Q_EMIT m_entry->imageChanged(m_entry->image());
+    Q_EMIT m_entry->cachedImageChanged(m_entry->cachedImage());
 }
 
 void Enclosure::deleteFile()
@@ -291,7 +294,7 @@ QString Enclosure::url() const
 
 QString Enclosure::path() const
 {
-    return StorageManager::instance().enclosurePath(m_url);
+    return StorageManager::instance().enclosurePath(m_entry->title(), m_url, m_entry->feed()->dirname());
 }
 
 Enclosure::Status Enclosure::status() const
@@ -302,7 +305,7 @@ Enclosure::Status Enclosure::status() const
 QString Enclosure::cachedEmbeddedImage() const
 {
     // if image is already cached, then return the path
-    QString cachedpath = StorageManager::instance().imagePath(path());
+    QString cachedpath = StorageManager::instance().imagePath(m_url);
     if (QFileInfo::exists(cachedpath)) {
         if (QFileInfo(cachedpath).size() != 0) {
             return QUrl::fromLocalFile(cachedpath).toString();
