@@ -72,6 +72,10 @@ void Entry::updateFromDb(bool emitSignals)
         m_new = entryQuery.value(QStringLiteral("new")).toBool();
         Q_EMIT newChanged(m_new);
     }
+    if (m_favorite != entryQuery.value(QStringLiteral("favorite")).toBool()) {
+        m_favorite = entryQuery.value(QStringLiteral("favorite")).toBool();
+        Q_EMIT favoriteChanged(m_favorite);
+    }
 
     setHasEnclosure(entryQuery.value(QStringLiteral("hasEnclosure")).toBool(), emitSignals);
     setImage(entryQuery.value(QStringLiteral("image")).toString(), emitSignals);
@@ -172,6 +176,11 @@ bool Entry::getNew() const
     return m_new;
 }
 
+bool Entry::favorite() const
+{
+    return m_favorite;
+}
+
 QString Entry::baseUrl() const
 {
     return QUrl(m_link).adjusted(QUrl::RemovePath).toString();
@@ -340,6 +349,34 @@ void Entry::setNewInternal(bool state)
     }
 }
 
+void Entry::setFavorite(bool favorite)
+{
+    if (favorite != m_favorite) {
+        // Making a detour through DataManager to make bulk operations more
+        // performant.  DataManager will call setFavoriteInternal on every item to
+        // be marked new/not new.  So implement features there.
+        DataManager::instance().bulkMarkFavorite(favorite, QStringList(m_id));
+    }
+}
+
+void Entry::setFavoriteInternal(bool favorite)
+{
+    if (favorite != m_favorite) {
+        // Make sure that operations done here can be wrapped inside an sqlite
+        // transaction.  I.e. no calls that trigger a SELECT operation.
+        m_favorite = favorite;
+        Q_EMIT favoriteChanged(m_favorite);
+
+        QSqlQuery query;
+        query.prepare(QStringLiteral("UPDATE Entries SET favorite=:favorite WHERE id=:id;"));
+        query.bindValue(QStringLiteral(":id"), m_id);
+        query.bindValue(QStringLiteral(":favorite"), m_favorite);
+        Database::instance().execute(query);
+
+        Q_EMIT DataManager::instance().favoriteEntryCountChanged(m_feed->url());
+    }
+}
+
 QString Entry::adjustedContent(int width, int fontSize)
 {
     QString ret(m_content);
@@ -401,11 +438,11 @@ bool Entry::hasEnclosure() const
 
 QString Entry::image() const
 {
-    if (!m_image.isEmpty()) {
-        return m_image;
-    } else if (m_hasenclosure && !m_enclosure->cachedEmbeddedImage().isEmpty()) {
+    if (m_hasenclosure && !m_enclosure->cachedEmbeddedImage().isEmpty()) {
         // use embedded image if available
         return m_enclosure->cachedEmbeddedImage();
+    } else if (!m_image.isEmpty()) {
+        return m_image;
     } else {
         // else fall back to feed image
         return m_feed->image();
@@ -414,16 +451,17 @@ QString Entry::image() const
 
 QString Entry::cachedImage() const
 {
-    // First check for the feed image, fall back if needed
+    // First check for an image in the downloaded file
+    if (m_hasenclosure && !m_enclosure->cachedEmbeddedImage().isEmpty()) {
+        // use embedded image if available
+        return m_enclosure->cachedEmbeddedImage();
+    }
+
+    // Then check for the entry image, fall back if needed to feed image
     QString image = m_image;
     if (image.isEmpty()) {
-        if (m_hasenclosure && !m_enclosure->cachedEmbeddedImage().isEmpty()) {
-            // use embedded image if available
-            return m_enclosure->cachedEmbeddedImage();
-        } else {
-            // else fall back to feed image
-            image = m_feed->image();
-        }
+        // else fall back to feed image
+        image = m_feed->image();
     }
 
     return Fetcher::instance().image(image);
