@@ -6,7 +6,6 @@
 
 #pragma once
 
-#include <QHash>
 #include <QItemSelection>
 #include <QModelIndex>
 #include <QObject>
@@ -14,15 +13,16 @@
 #include <QVariant>
 
 #include "models/abstractepisodemodel.h"
+#include "models/abstractepisodeproxymodel.h"
 
 class QueueModel : public AbstractEpisodeModel
 {
     Q_OBJECT
 
+public:
     Q_PROPERTY(int timeLeft READ timeLeft NOTIFY timeLeftChanged)
     Q_PROPERTY(QString formattedTimeLeft READ formattedTimeLeft NOTIFY timeLeftChanged)
 
-public:
     static QueueModel &instance()
     {
         static QueueModel _instance;
@@ -35,6 +35,9 @@ public:
     int timeLeft() const;
     QString formattedTimeLeft() const;
 
+    Q_INVOKABLE static QString getSortName(AbstractEpisodeProxyModel::SortType type);
+    Q_INVOKABLE static QString getSortIconName(AbstractEpisodeProxyModel::SortType type);
+
     Q_INVOKABLE QItemSelection createSelection(int rowa, int rowb);
 
 public Q_SLOTS:
